VerifyingKey

Struct VerifyingKey 

pub struct VerifyingKey(/* private fields */);
Verifying key for Ed25519 signatures

Used to verify signatures created by the corresponding SigningKey.

Examples

use aion_context::crypto::{SigningKey, VerifyingKey};

let signing_key = SigningKey::generate();
let verifying_key = signing_key.verifying_key();

let message = b"test";
let signature = signing_key.sign(message);

assert!(verifying_key.verify(message, &signature).is_ok());

Implementations

Source

impl VerifyingKey

pub fn from_bytes(bytes: &[u8]) -> Result<Self>

Create a verifying key from bytes

Errors

Returns AionError::InvalidPublicKey if the bytes are not a valid Ed25519 public key

pub fn to_bytes(&self) -> [u8; 32]

Get the bytes of this verifying key

pub fn verify(&self, message: &[u8], signature: &[u8; 64]) -> Result<()>

Verify a signature on a message

Errors

Returns AionError::InvalidSignature if the signature is invalid or doesn’t match the message