pub struct SignatureAggregator { /* private fields */ }Expand description
Aggregate multiple signatures for a version
This collects signatures from multiple signers into a single list that can be stored with the version.
Implementations
Sourceimpl SignatureAggregator
impl SignatureAggregator
Sourcepub fn add_signature(&mut self, signature: SignatureEntry)
pub fn add_signature(&mut self, signature: SignatureEntry)
Add a signature to the aggregation
Sourcepub fn signatures(&self) -> &[SignatureEntry]
pub fn signatures(&self) -> &[SignatureEntry]
Get the collected signatures
Sourcepub fn into_signatures(self) -> Vec<SignatureEntry>
pub fn into_signatures(self) -> Vec<SignatureEntry>
Consume and return the signatures