pub struct SignedTreeHead {
pub tree_size: u64,
pub root_hash: [u8; 32],
pub operator_signature: [u8; 64],
}Expand description
A tree head signed by the log operator.
Fields
tree_size: u64Number of leaves in the tree at signing time.
root_hash: [u8; 32]Merkle root hash at that tree size.
operator_signature: [u8; 64]Ed25519 signature by the operator master key over the canonical STH bytes.