pub struct VerifyingKey(/* private fields */);Expand description
Verifying key for Ed25519 signatures
Used to verify signatures created by the corresponding SigningKey.
Examples
use aion_context::crypto::{SigningKey, VerifyingKey};
let signing_key = SigningKey::generate();
let verifying_key = signing_key.verifying_key();
let message = b"test";
let signature = signing_key.sign(message);
assert!(verifying_key.verify(message, &signature).is_ok());Implementations
Sourceimpl VerifyingKey
impl VerifyingKey
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self>
pub fn from_bytes(bytes: &[u8]) -> Result<Self>
Create a verifying key from bytes
Errors
Returns AionError::InvalidPublicKey if the bytes are not a valid Ed25519 public key